/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.framework;

/**
 * Interface for generator extensions, which require code generation on an instance level, e.g.,
 * every sensor of a certain type has its own instance data.
 * <P>
 * Implementors of this interface receive a {@code postfix} via {@link #setInstancePostfix(String)},
 * which is unique for every model element instance.
 * 
 * @author hoelzl
 */
public interface IInstanceGeneratorExtension {
	/** Instance postfix set by the code generator to ensure unique instance identifiers. */
	void setInstancePostfix(String instancePostfix);

	/** Returns the variable declarations needed by this executable. */
	String getInstanceVariableDeclaration();

	/** Returns the auxiliary function code needed by this executable. */
	String getInstanceAuxiliaryFunctions();

	/** Returns the initialization code. */
	String getInstanceInitializationCode();

	/** Returns an termination code for the given {@code postfix}. */
	String getInstanceTerminationCode();
}
